Option Strict On

Imports System.Management

Public Class WQL_Samples
    Shared Sub EventWatcher()
        Dim objEventWatcher As New ManagementEventWatcher(New WqlEventQuery("SELECT * FROM __InstanceCreationEvent WHERE TargetInstance ISA 'Win32_NTLogEvent'"))
        Dim objEventArrivedMethod As New WQL_Samples()
        AddHandler objEventWatcher.EventArrived, AddressOf objEventArrivedMethod.Updated

        ' Start watching for events
        objEventWatcher.Start()

        ' Create an Event Log Entry
        Dim objEventLog As New System.Diagnostics.EventLog("Application")
        System.Threading.Thread.Sleep(2000)
        objEventLog.Source = "WQL Sample 1"
        objEventLog.WriteEntry("Sample WQL Entry 1...")

        ' Allow time for the event to fire before we stop notifications
        System.Threading.Thread.Sleep(2000)

        objEventWatcher.Stop() ' Stops waiting for events.
    End Sub
    Shared Sub EventWatcherApplication()
        Dim objEventWatcher As New ManagementEventWatcher(New WqlEventQuery("SELECT * FROM __InstanceCreationEvent WITHIN 60 WHERE TargetInstance ISA 'Win32_NTLogEvent' AND TargetInstance.Logfile = 'System'"))
        Dim objEventArrivedMethod As New WQL_Samples()
        AddHandler objEventWatcher.EventArrived, AddressOf objEventArrivedMethod.Updated

        ' Start watching for events
        objEventWatcher.Start()

        ' Create an Event Log Entry
        Dim objEventLog As New System.Diagnostics.EventLog("Application")
        objEventLog.Source = "WQL Sample 1"
        objEventLog.WriteEntry("Sample WQL Entry 1...")

        System.Threading.Thread.Sleep(200)
        objEventLog.WriteEntry("Sample WQL Entry 2...")
        System.Threading.Thread.Sleep(200)

        ' Allow time for the event to fire before we stop notifications
        System.Threading.Thread.Sleep(2000)

        objEventWatcher.Stop() ' Stops waiting for events.
    End Sub
    Sub Updated(ByVal sender As Object, ByVal e As EventArrivedEventArgs)
        Dim objClassInstance As ManagementBaseObject

        objClassInstance = CType(e.NewEvent.Properties("TargetInstance").Value, ManagementBaseObject)
        MessageBox.Show("The following entry was just added: " & objClassInstance.Properties("LogFile").Value.ToString & ": " & objClassInstance.Properties("Message").Value.ToString)
    End Sub
    Shared Sub UserEventWatcher()
        Dim objScope As New ManagementScope("\\.\root\cimv2")

        Try
            Dim objEventWatcher As New ManagementEventWatcher(objScope, New WqlEventQuery("SELECT * FROM NewUserEventHandler"))
            ' Note this use of a shared method in this example
            'AddHandler objEventWatcher.EventArrived, AddressOf WQL_Samples.UserUpdated

            Dim objEventArrivedMethod As New WQL_Samples()
            AddHandler objEventWatcher.EventArrived, AddressOf objEventArrivedMethod.UserUpdated

            ' Start watching for events
            objEventWatcher.Start()

            ' Allow time for the event to fire before we stop notifications
            Dim i As Integer
            For i = 1 To 300
                System.Threading.Thread.Sleep(100)
            Next

            objEventWatcher.Stop() ' Stops waiting for events.
        Catch ex As Exception
            MessageBox.Show("Source: " & ex.Source & vbCrLf & "Message: " & ex.Message & vbCrLf & vbCrLf & ex.StackTrace)
        End Try
    End Sub
    Shared Sub UserUpdated(ByVal sender As Object, ByVal e As EventArrivedEventArgs)
        Dim objClassInstance As ManagementBaseObject

        objClassInstance = CType(e.NewEvent.Properties("TargetInstance").Value, ManagementBaseObject)
        MessageBox.Show("The following entry was just added: " & objClassInstance.Properties("Username").Value.ToString & ": " & objClassInstance.Properties("Message").Value.ToString)
    End Sub
    Shared Sub IterateApplicationEventLog()
        Dim objScope As New ManagementScope("\\.\root\cimv2")
        Dim objWMIQuery As New Management.SelectQuery("Win32_NTLogEvent")
        With objWMIQuery
            .Condition = "Logfile = 'Application' and Type='error'"
        End With
        Dim objWMISearcher As New ManagementObjectSearcher(objScope, objWMIQuery)
        Dim objWMIClass As ManagementBaseObject

        For Each objWMIClass In objWMISearcher.Get()
            Debug.WriteLine(objWMIClass.Properties("SourceName").Value.ToString)
        Next
    End Sub
    Public Shared Sub AssociatorsOF()
        'This query requests all objects related to the 'C:' drive.
        Dim objWMIQuery As New RelatedObjectQuery("win32_logicaldisk='c:'")
        Dim objWMISearcher As New ManagementObjectSearcher(objWMIQuery)

        Dim objClass As ManagementObject
        ' Now iterate through each of the associations return by the query
        For Each objClass In objWMISearcher.Get()
            Debug.WriteLine(objClass.ToString())
        Next
    End Sub
    Shared Sub LateBound()
        Dim objWMISearcher As New ManagementObjectSearcher("SELECT * FROM Win32_LogicalDisk WHERE DeviceID='C:'")
        Dim objDrive As ManagementObject

        For Each objDrive In objWMISearcher.Get
            MsgBox("You have :" & objDrive.Properties("FreeSpace").Value.ToString & " bytes free.")
        Next
    End Sub
    Shared Sub EarlyBound()
        Dim objLogicalDisk As New ROOT.CIMV2.LogicalDisk("C:")

        MsgBox("You have :" & objLogicalDisk.FreeSpace.ToString & " bytes free.")
    End Sub
    Shared Sub RemoveNamespaceSchema()
        Dim strNamespace, strNamespaceLeft, strNamespaceRight As String
        Dim intPos As Integer

        strNamespace = InputBox("Please enter the namespace to remove" & vbCrLf & "(eg: root\samples)", "WARNING: Namespace removal", "<enter namesapce>")

        ' break the namespace into the parent namespace and the namespace name
        intPos = InStrRev(strNamespace, "\")
        If intPos <> 0 Then strNamespaceLeft = Left(strNamespace, intPos - 1)
        strNamespaceRight = Right(strNamespace, Len(strNamespace) - intPos)

        Dim objScope As New ManagementScope("\\.\" & strNamespaceLeft)
        Dim objWMIQuery As New Management.SelectQuery("Select * from __Namespace where name='" & strNamespaceRight)
        Dim objWMISearcher As New ManagementObjectSearcher(objScope, objWMIQuery)
        Dim objWMIClass As ManagementClass

        For Each objWMIClass In objWMISearcher.Get()
            'objWMIClass.Delete()
            Debug.WriteLine(objWMIClass.Properties("SourceName").Value.ToString)
        Next
        ' connect to the parent namespace
    End Sub
    Shared Sub ModifyVolumeName()
        Dim objScope As New ManagementScope("\\.\root\cimv2")
        Dim objWMISearcher As New ManagementObjectSearcher(objScope, New SelectQuery("SELECT * FROM Win32_LogicalDisk where DeviceID='C:'"))
        Dim objDrive As ManagementObject
        Try
            For Each objDrive In objWMISearcher.Get
                objDrive.Properties("VolumeName").Value = _
                    InputBox("Enter New Name for Drive C:", "Change Caption")
                objDrive.Put()
            Next
        Catch ex As Exception
            MessageBox.Show(ex.Message)
        Finally
        End Try
    End Sub
    Shared Sub ModifyVolumeNameAsync()
        Dim objScope As New ManagementScope("\\.\root\cimv2")
        Dim objWMISearcher As New ManagementObjectSearcher(objScope, New SelectQuery("SELECT * FROM Win32_LogicalDisk where DeviceID='C:'"))
        Dim objDrive As ManagementObject
        Try
            Dim objObserver As New ManagementOperationObserver()
            AddHandler objObserver.Completed, AddressOf WQL_Samples.ModifyVolumeNameAsyncComplete
            For Each objDrive In objWMISearcher.Get
                objDrive.Properties("VolumeName").Value = _
                    InputBox("Enter New Name for Drive C:", "Change Caption")
                ' Here we tell the method how to handle the async operation
                objDrive.Put(objObserver)
            Next
        Catch ex As Exception
            MessageBox.Show(ex.Message)
        End Try
    End Sub
    Shared Sub ModifyVolumeNameAsyncComplete(ByVal sender As Object, ByVal e As CompletedEventArgs)
        MessageBox.Show("Drive Volume update is complete.")
    End Sub
End Class

